==> open-cluster-management-observability-model-6.4.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/MultiClusterObservabilityFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MultiClusterObservabilityFluentImpl<A extends MultiClusterObservabilityFluent<A>> extends BaseFluent<A> implements MultiClusterObservabilityFluent<A>{
  public MultiClusterObservabilityFluentImpl() {
  }
  public MultiClusterObservabilityFluentImpl(MultiClusterObservability instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private MultiClusterObservabilitySpecBuilder spec;
  private MultiClusterObservabilityStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public MultiClusterObservabilityFluent.MetadataNested<A> withNewMetadata() {
    return new MultiClusterObservabilityFluentImpl.MetadataNestedImpl();
  }
  public MultiClusterObservabilityFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MultiClusterObservabilityFluentImpl.MetadataNestedImpl(item);
  }
  public MultiClusterObservabilityFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public MultiClusterObservabilityFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public MultiClusterObservabilityFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public MultiClusterObservabilitySpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public MultiClusterObservabilitySpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(MultiClusterObservabilitySpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new MultiClusterObservabilitySpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public MultiClusterObservabilityFluent.SpecNested<A> withNewSpec() {
    return new MultiClusterObservabilityFluentImpl.SpecNestedImpl();
  }
  public MultiClusterObservabilityFluent.SpecNested<A> withNewSpecLike(MultiClusterObservabilitySpec item) {
    return new MultiClusterObservabilityFluentImpl.SpecNestedImpl(item);
  }
  public MultiClusterObservabilityFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public MultiClusterObservabilityFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new MultiClusterObservabilitySpecBuilder().build());
  }
  public MultiClusterObservabilityFluent.SpecNested<A> editOrNewSpecLike(MultiClusterObservabilitySpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public MultiClusterObservabilityStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public MultiClusterObservabilityStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(MultiClusterObservabilityStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new MultiClusterObservabilityStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public MultiClusterObservabilityFluent.StatusNested<A> withNewStatus() {
    return new MultiClusterObservabilityFluentImpl.StatusNestedImpl();
  }
  public MultiClusterObservabilityFluent.StatusNested<A> withNewStatusLike(MultiClusterObservabilityStatus item) {
    return new MultiClusterObservabilityFluentImpl.StatusNestedImpl(item);
  }
  public MultiClusterObservabilityFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public MultiClusterObservabilityFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new MultiClusterObservabilityStatusBuilder().build());
  }
  public MultiClusterObservabilityFluent.StatusNested<A> editOrNewStatusLike(MultiClusterObservabilityStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MultiClusterObservabilityFluentImpl that = (MultiClusterObservabilityFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MultiClusterObservabilityFluent.MetadataNested<N>> implements MultiClusterObservabilityFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) MultiClusterObservabilityFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends MultiClusterObservabilitySpecFluentImpl<MultiClusterObservabilityFluent.SpecNested<N>> implements MultiClusterObservabilityFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(MultiClusterObservabilitySpec item) {
      this.builder = new MultiClusterObservabilitySpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new MultiClusterObservabilitySpecBuilder(this);
    }
    MultiClusterObservabilitySpecBuilder builder;
    public N and() {
      return (N) MultiClusterObservabilityFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends MultiClusterObservabilityStatusFluentImpl<MultiClusterObservabilityFluent.StatusNested<N>> implements MultiClusterObservabilityFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(MultiClusterObservabilityStatus item) {
      this.builder = new MultiClusterObservabilityStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new MultiClusterObservabilityStatusBuilder(this);
    }
    MultiClusterObservabilityStatusBuilder builder;
    public N and() {
      return (N) MultiClusterObservabilityFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-observability-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/MultiClusterObservabilityFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MultiClusterObservabilityFluentImpl<A extends MultiClusterObservabilityFluent<A>> extends BaseFluent<A> implements MultiClusterObservabilityFluent<A>{
  public MultiClusterObservabilityFluentImpl() {
  }
  public MultiClusterObservabilityFluentImpl(MultiClusterObservability instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private MultiClusterObservabilitySpecBuilder spec;
  private MultiClusterObservabilityStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public MultiClusterObservabilityFluentImpl.MetadataNested<A> withNewMetadata() {
    return new MultiClusterObservabilityFluentImpl.MetadataNestedImpl();
  }
  public MultiClusterObservabilityFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MultiClusterObservabilityFluentImpl.MetadataNestedImpl(item);
  }
  public MultiClusterObservabilityFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public MultiClusterObservabilityFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public MultiClusterObservabilityFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public MultiClusterObservabilitySpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public MultiClusterObservabilitySpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(MultiClusterObservabilitySpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new MultiClusterObservabilitySpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public MultiClusterObservabilityFluentImpl.SpecNested<A> withNewSpec() {
    return new MultiClusterObservabilityFluentImpl.SpecNestedImpl();
  }
  public MultiClusterObservabilityFluentImpl.SpecNested<A> withNewSpecLike(MultiClusterObservabilitySpec item) {
    return new MultiClusterObservabilityFluentImpl.SpecNestedImpl(item);
  }
  public MultiClusterObservabilityFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public MultiClusterObservabilityFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new MultiClusterObservabilitySpecBuilder().build());
  }
  public MultiClusterObservabilityFluentImpl.SpecNested<A> editOrNewSpecLike(MultiClusterObservabilitySpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public MultiClusterObservabilityStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public MultiClusterObservabilityStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(MultiClusterObservabilityStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new MultiClusterObservabilityStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public MultiClusterObservabilityFluentImpl.StatusNested<A> withNewStatus() {
    return new MultiClusterObservabilityFluentImpl.StatusNestedImpl();
  }
  public MultiClusterObservabilityFluentImpl.StatusNested<A> withNewStatusLike(MultiClusterObservabilityStatus item) {
    return new MultiClusterObservabilityFluentImpl.StatusNestedImpl(item);
  }
  public MultiClusterObservabilityFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public MultiClusterObservabilityFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new MultiClusterObservabilityStatusBuilder().build());
  }
  public MultiClusterObservabilityFluentImpl.StatusNested<A> editOrNewStatusLike(MultiClusterObservabilityStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MultiClusterObservabilityFluentImpl that = (MultiClusterObservabilityFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MultiClusterObservabilityFluentImpl.MetadataNested<N>> implements MultiClusterObservabilityFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) MultiClusterObservabilityFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends MultiClusterObservabilitySpecFluentImpl<MultiClusterObservabilityFluentImpl.SpecNested<N>> implements MultiClusterObservabilityFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(MultiClusterObservabilitySpec item) {
      this.builder = new MultiClusterObservabilitySpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new MultiClusterObservabilitySpecBuilder(this);
    }
    MultiClusterObservabilitySpecBuilder builder;
    public N and() {
      return (N) MultiClusterObservabilityFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends MultiClusterObservabilityStatusFluentImpl<MultiClusterObservabilityFluentImpl.StatusNested<N>> implements MultiClusterObservabilityFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(MultiClusterObservabilityStatus item) {
      this.builder = new MultiClusterObservabilityStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new MultiClusterObservabilityStatusBuilder(this);
    }
    MultiClusterObservabilityStatusBuilder builder;
    public N and() {
      return (N) MultiClusterObservabilityFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
